Intel® Threading Building Blocks (Intel® TBB). Samples on Intel® TBB Flow Graph feature

# Intel® Threading Building Blocks (Intel® TBB).
Samples on Intel® TBB Flow Graph feature

This directory has examples of the Intel TBB Flow Graph feature.

Directories

dining_philosophers
  An implementation of dining philosophers in graph using the reserving join node.
binpack
  A solution to the binpacking problem using a `queue_node`, a `buffer_node` and `function_nodes`.
logic_sim
  A simplistic example of a collection of digital logic gates that can be easily composed into larger circuits.
som
  A simple example of a Kohonen Self-Organizing Map using cancellation.
fgbzip2
  A parallel implementation of bzip2 block-sorting file compressor.
cholesky
  Several versions of Cholesky Factorization algorithm implementation.
stereo
  An implementation of stereo image creation from two images (anaglyph effect).
matmult
  Matrix multiplication Gen kernel implementation with the flow graph interface.

Up to parent directory

Legal Information:

Intel and the Intel logo are trademarks of Intel Corporation in the U.S. and/or other countries.
* Other names and brands may be claimed as the property of others.
© 2018, Intel Corporation